# Updated 2021 December 15

#### CODE PREAMBLE AND DESCRIPTION ####

## Code preamble: prepare workspace and load R packages

rm(list = ls())     # Clear workspace
library(augsynth)   # R package for synthetic control estimation
library(ggplot2)    # R package for plotting graphs
library(data.table) # R package for using data.tables as augmented data.frames
datadir = "~/Dropbox/Shared/VaccineLotteries/BarberWest_CodeData_Final/data" # SET THIS: top-level data directory
figuresdir = "~/Dropbox/Shared/VaccineLotteries/BarberWest_CodeData_Final/figures" # SET THIS: directory in which to save figures
setwd(datadir)

## Generates one figure for each outcome:
#
#  - Coefficients and 95 percent confidence intervals plot for various robustness checks for the
#     Synthetic Control difference estimation using total dose 1 vaccinations per 100 state population
#
#  - Coefficients and 95 percent confidence intervals plot for various robustness checks for the
#     Synthetic Control difference estimation using total COVID-19 cases per 100,000 population
#
#  - Coefficients and 95 percent confidence intervals plot for various robustness checks for the
#     Synthetic Control difference estimation using total COVID-19 ICU patient-days per 100,000 population
#
#

## Generates one figure of ratios of the post- and pre-treatment RMSPE for placebo tests using donor pool states
#

## Data and programming notes:
#
# 1. Running this code requires fairly little computer RAM, less than 2 GB. 
#
# 2. The data are a balanced panel of the 50 states and D.C., with data starting:
#     - February 19, 2021 for dose 1 vaccinations (Pfizer and Moderna, as this was pre-Janssen)
#     - March 4, 2021 for dose 2 outcomes (Pfizer and Moderna), earliest non-zero values in CDC's data
#     - March 5, 2021 for Janssen vaccinations (always dose 1)
#     - February 19, 2021 for COVID-19 outcomes (authors' decision, to be consistent)
#       The full panel of data has COVID-19 outcomes starting March 1, 2020
# 
# 3. June 20, 2021 was the end-date for Ohio's vaccine incentive program.
#

#### LOAD AND PREPARE DATA ####

panel <- fread("analysis_panel.csv")
setkey(panel, fips, date)

# Subset the panel to data after the starting date and ending date to be used for each outcome

mindate.panel = "2021-02-19"        # Earliest available data
maxdate.vaccinations = "2021-06-20" # Ohio's program end date
maxdate.cases <- max((panel[!is.na(covid_new_cases)]$date))
maxdate.icu <- max((panel[!is.na(covid_icu_patdays_per100kpop)]$date))

synthpanel.dose1 <- panel[date >= mindate.panel & date <= maxdate.vaccinations]
synthpanel.cases <- panel[date >= mindate.panel & date <= maxdate.cases]
synthpanel.icu <- panel[date >= mindate.panel & date <= maxdate.icu]

#### ESTIMATE THE BASELINE MODEL FOR EACH OUTCOME AND EXTRACT THE TREATMENT EFFECTS TABLES ####

# Estimation: total dose 1 vaccinations per 100 state population

baseline.panel.dose1 <- copy(synthpanel.dose1[(fips == 39 | donor_pool == 1)])

baseline.est.dose1 <- augsynth(dose1_per_100pop ~ ohio_post |
                                 popdensity_2020 +
                                 gdp_per_capita_2020 +
                                 gop_pct_2020 +
                                 influenza_vaccination_pct_2019 +
                                 moveidx_retail_recreation +
                                 moveidx_grocery_pharmacy +
                                 moveidx_parks +
                                 moveidx_transit +
                                 moveidx_workplaces +
                                 moveidx_residential +
                                 miles_vacsite_50th_pctl +
                                 miles_vacsite_95th_pctl
                               , unit = fips, time = date, data = baseline.panel.dose1, progfun = "Ridge", fixedeff = TRUE)

baseline.results.dose1 <- summary(baseline.est.dose1, inf = TRUE, inf_type = "conformal")$att
baseline.results.dose1 <- cbind(data.table(baseline.results.dose1)[Time >= "2021-05-12"], data.table(model = "Baseline model"))

# Estimation: total COVID-19 cases per 100,000 state population

baseline.panel.cases <- copy(synthpanel.cases[(fips == 39 | donor_pool == 1)])

baseline.est.cases <- augsynth(covid_total_cases_per100kpop ~ ohio_post |
                                 popdensity_2020 +
                                 gdp_per_capita_2020 +
                                 gop_pct_2020 +
                                 influenza_vaccination_pct_2019 +
                                 moveidx_retail_recreation +
                                 moveidx_grocery_pharmacy +
                                 moveidx_parks +
                                 moveidx_transit +
                                 moveidx_workplaces +
                                 moveidx_residential +
                                 miles_vacsite_50th_pctl +
                                 miles_vacsite_95th_pctl
                               , unit = fips, time = date, data = baseline.panel.cases, progfun = "Ridge", fixedeff = TRUE)

baseline.results.cases <- summary(baseline.est.cases, inf = TRUE, inf_type = "conformal")$att
baseline.results.cases <- cbind(data.table(baseline.results.cases)[Time >= "2021-05-12"], data.table(model = "Baseline model"))

# Estimation: cumulative total COVID-19 ICU patient-days per 100,000 population

baseline.panel.icu <- copy(synthpanel.icu[(fips == 39 | donor_pool == 1)])

baseline.est.icu <- augsynth(covid_icu_patdays_per100kpop ~ ohio_post |
                               popdensity_2020 +
                               gdp_per_capita_2020 +
                               gop_pct_2020 +
                               influenza_vaccination_pct_2019 +
                               moveidx_retail_recreation +
                               moveidx_grocery_pharmacy +
                               moveidx_parks +
                               moveidx_transit +
                               moveidx_workplaces +
                               moveidx_residential +
                               miles_vacsite_50th_pctl +
                               miles_vacsite_95th_pctl
                             , unit = fips, time = date, data = baseline.panel.icu, progfun = "Ridge", fixedeff = TRUE)

baseline.results.icu <- summary(baseline.est.icu, inf = TRUE, inf_type = "conformal")$att
baseline.results.icu <- cbind(data.table(baseline.results.icu)[Time >= "2021-05-12"], data.table(model = "Baseline model"))

# Clean up the workspace

rm(baseline.panel.dose1, baseline.panel.cases, baseline.panel.icu, baseline.est.dose1, baseline.est.cases, baseline.est.icu)

#### ESTIMATE AN ALTERNATIVE MODEL FOR EACH OUTCOME AND EXTRACT THE TREATMENT EFFECTS TABLES: CLASSIC SCM  ####

# Estimation: total dose 1 vaccinations per 100 state population

classicscm.panel.dose1 <- copy(synthpanel.dose1[(fips == 39 | donor_pool == 1)])

classicscm.est.dose1 <- augsynth(dose1_per_100pop ~ ohio_post
                                 , unit = fips, time = date, data = classicscm.panel.dose1, progfun = "None", fixedeff = FALSE)

classicscm.results.dose1 <- summary(classicscm.est.dose1, inf = TRUE, inf_type = "conformal")$att
classicscm.results.dose1 <- cbind(data.table(classicscm.results.dose1)[Time >= "2021-05-12"], data.table(model = "Classic SCM"))

# Estimation: total COVID-19 cases per 100,000 state population

classicscm.panel.cases <- copy(synthpanel.cases[(fips == 39 | donor_pool == 1)])

classicscm.est.cases <- augsynth(covid_total_cases_per100kpop ~ ohio_post
                                 , unit = fips, time = date, data = classicscm.panel.cases, progfun = "None", fixedeff = FALSE)

classicscm.results.cases <- summary(classicscm.est.cases, inf = TRUE, inf_type = "conformal")$att
classicscm.results.cases <- cbind(data.table(classicscm.results.cases)[Time >= "2021-05-12"], data.table(model = "Classic SCM"))

# Estimation: cumulative total COVID-19 ICU patient-days per 100,000 population

classicscm.panel.icu <- copy(synthpanel.icu[(fips == 39 | donor_pool == 1)])

classicscm.est.icu <- augsynth(covid_icu_patdays_per100kpop ~ ohio_post
                               , unit = fips, time = date, data = classicscm.panel.icu, progfun = "None", fixedeff = FALSE)

classicscm.results.icu <- summary(classicscm.est.icu, inf = TRUE, inf_type = "conformal")$att
classicscm.results.icu <- cbind(data.table(classicscm.results.icu)[Time >= "2021-05-12"], data.table(model = "Classic SCM"))

# Clean up the workspace

rm(classicscm.panel.dose1, classicscm.panel.cases, classicscm.panel.icu, classicscm.est.dose1, classicscm.est.cases, classicscm.est.icu)

#### ESTIMATE AN ALTERNATIVE MODEL FOR EACH OUTCOME AND EXTRACT THE TREATMENT EFFECTS TABLES: RESIDUALIZED TO COVARIATES ####

# Estimation: total dose 1 vaccinations per 100 state population

residualized.panel.dose1 <- copy(synthpanel.dose1[(fips == 39 | donor_pool == 1)])

residualized.est.dose1 <- augsynth(dose1_per_100pop ~ ohio_post |
                                 popdensity_2020 +
                                 gdp_per_capita_2020 +
                                 gop_pct_2020 +
                                 influenza_vaccination_pct_2019 +
                                 moveidx_retail_recreation +
                                 moveidx_grocery_pharmacy +
                                 moveidx_parks +
                                 moveidx_transit +
                                 moveidx_workplaces +
                                 moveidx_residential +
                                 miles_vacsite_50th_pctl +
                                 miles_vacsite_95th_pctl
                               , unit = fips, time = date, data = residualized.panel.dose1, progfun = "Ridge", fixedeff = TRUE, residualize = TRUE)

residualized.results.dose1 <- summary(residualized.est.dose1, inf = TRUE, inf_type = "conformal")$att
residualized.results.dose1 <- cbind(data.table(residualized.results.dose1)[Time >= "2021-05-12"], data.table(model = "Residualized to covariates"))

# Estimation: total COVID-19 cases per 100,000 state population

residualized.panel.cases <- copy(synthpanel.cases[(fips == 39 | donor_pool == 1)])

residualized.est.cases <- augsynth(covid_total_cases_per100kpop ~ ohio_post |
                                 popdensity_2020 +
                                 gdp_per_capita_2020 +
                                 gop_pct_2020 +
                                 influenza_vaccination_pct_2019 +
                                 moveidx_retail_recreation +
                                 moveidx_grocery_pharmacy +
                                 moveidx_parks +
                                 moveidx_transit +
                                 moveidx_workplaces +
                                 moveidx_residential +
                                 miles_vacsite_50th_pctl +
                                 miles_vacsite_95th_pctl
                               , unit = fips, time = date, data = residualized.panel.cases, progfun = "Ridge", fixedeff = TRUE, residualize = TRUE)

residualized.results.cases <- summary(residualized.est.cases, inf = TRUE, inf_type = "conformal")$att
residualized.results.cases <- cbind(data.table(residualized.results.cases)[Time >= "2021-05-12"], data.table(model = "Residualized to covariates"))

# Estimation: cumulative total COVID-19 ICU patient-days per 100,000 population

residualized.panel.icu <- copy(synthpanel.icu[(fips == 39 | donor_pool == 1)])

residualized.est.icu <- augsynth(covid_icu_patdays_per100kpop ~ ohio_post |
                               popdensity_2020 +
                               gdp_per_capita_2020 +
                               gop_pct_2020 +
                               influenza_vaccination_pct_2019 +
                               moveidx_retail_recreation +
                               moveidx_grocery_pharmacy +
                               moveidx_parks +
                               moveidx_transit +
                               moveidx_workplaces +
                               moveidx_residential +
                               miles_vacsite_50th_pctl +
                               miles_vacsite_95th_pctl
                             , unit = fips, time = date, data = residualized.panel.icu, progfun = "Ridge", fixedeff = TRUE, residualize = TRUE)

residualized.results.icu <- summary(residualized.est.icu, inf = TRUE, inf_type = "conformal")$att
residualized.results.icu <- cbind(data.table(residualized.results.icu)[Time >= "2021-05-12"], data.table(model = "Residualized to covariates"))

# Clean up the workspace

rm(residualized.panel.dose1, residualized.panel.cases, residualized.panel.icu, residualized.est.dose1, residualized.est.cases, residualized.est.icu)

#### ESTIMATE AN ALTERNATIVE MODEL FOR EACH OUTCOME AND EXTRACT THE TREATMENT EFFECTS TABLES: USING ALL 50 STATES  ####

# Estimation: total dose 1 vaccinations per 100 state population

allstates.panel.dose1 <- copy(synthpanel.dose1)

allstates.est.dose1 <- augsynth(dose1_per_100pop ~ ohio_post |
                                 popdensity_2020 +
                                 gdp_per_capita_2020 +
                                 gop_pct_2020 +
                                 influenza_vaccination_pct_2019 +
                                 moveidx_retail_recreation +
                                 moveidx_grocery_pharmacy +
                                 moveidx_parks +
                                 moveidx_transit +
                                 moveidx_workplaces +
                                 moveidx_residential +
                                 miles_vacsite_50th_pctl +
                                 miles_vacsite_95th_pctl
                               , unit = fips, time = date, data = allstates.panel.dose1, progfun = "Ridge", fixedeff = TRUE)

allstates.results.dose1 <- summary(allstates.est.dose1, inf = TRUE, inf_type = "conformal")$att
allstates.results.dose1 <- cbind(data.table(allstates.results.dose1)[Time >= "2021-05-12"], data.table(model = "Including all 50 states"))

# Estimation: total COVID-19 cases per 100,000 state population

allstates.panel.cases <- copy(synthpanel.cases)

allstates.est.cases <- augsynth(covid_total_cases_per100kpop ~ ohio_post |
                                 popdensity_2020 +
                                 gdp_per_capita_2020 +
                                 gop_pct_2020 +
                                 influenza_vaccination_pct_2019 +
                                 moveidx_retail_recreation +
                                 moveidx_grocery_pharmacy +
                                 moveidx_parks +
                                 moveidx_transit +
                                 moveidx_workplaces +
                                 moveidx_residential +
                                 miles_vacsite_50th_pctl +
                                 miles_vacsite_95th_pctl
                               , unit = fips, time = date, data = allstates.panel.cases, progfun = "Ridge", fixedeff = TRUE)

allstates.results.cases <- summary(allstates.est.cases, inf = TRUE, inf_type = "conformal")$att
allstates.results.cases <- cbind(data.table(allstates.results.cases)[Time >= "2021-05-12"], data.table(model = "Including all 50 states"))

# Estimation: cumulative total COVID-19 ICU patient-days per 100,000 population

allstates.panel.icu <- copy(synthpanel.icu)

allstates.est.icu <- augsynth(covid_icu_patdays_per100kpop ~ ohio_post |
                               popdensity_2020 +
                               gdp_per_capita_2020 +
                               gop_pct_2020 +
                               influenza_vaccination_pct_2019 +
                               moveidx_retail_recreation +
                               moveidx_grocery_pharmacy +
                               moveidx_parks +
                               moveidx_transit +
                               moveidx_workplaces +
                               moveidx_residential +
                               miles_vacsite_50th_pctl +
                               miles_vacsite_95th_pctl
                             , unit = fips, time = date, data = allstates.panel.icu, progfun = "Ridge", fixedeff = TRUE)

allstates.results.icu <- summary(allstates.est.icu, inf = TRUE, inf_type = "conformal")$att
allstates.results.icu <- cbind(data.table(allstates.results.icu)[Time >= "2021-05-12"], data.table(model = "Including all 50 states"))

# Clean up the workspace

rm(allstates.panel.dose1, allstates.panel.cases, allstates.panel.icu, allstates.est.dose1, allstates.est.cases, allstates.est.icu)

#### ESTIMATE AN ALTERNATIVE MODEL FOR EACH OUTCOME AND EXTRACT THE TREATMENT EFFECTS TABLES: LEAVE-ONE-OUT FOR ALL POSSIBLE DONOR UNITS  ####

donor_states_list <- unique(synthpanel.dose1[donor_pool == 1]$stname)

# Estimation: total dose 1 vaccinations per 100 state population

baseline.panel.dose1 <- copy(synthpanel.dose1[(fips == 39 | donor_pool == 1)])

leave.one.out.results.dose1.dtl <- lapply(1:length(donor_states_list), function(s) {
  print(paste0("Estimating model for dose 1 leaving out ", donor_states_list[s]))
  leave.one.out.est <- augsynth(dose1_per_100pop ~ ohio_post |
                                  popdensity_2020 +
                                  gdp_per_capita_2020 +
                                  gop_pct_2020 +
                                  influenza_vaccination_pct_2019 +
                                  moveidx_retail_recreation +
                                  moveidx_grocery_pharmacy +
                                  moveidx_parks +
                                  moveidx_transit +
                                  moveidx_workplaces +
                                  moveidx_residential +
                                  miles_vacsite_50th_pctl +
                                  miles_vacsite_95th_pctl
                                , unit = fips, time = date, 
                                data = baseline.panel.dose1[stname != donor_states_list[s]], progfun = "Ridge", fixedeff = TRUE)
  leave.one.out.results <- summary(leave.one.out.est , inf = TRUE, inf_type = "conformal")$att
  leave.one.out.results <- cbind(data.table(leave.one.out.results)[Time >= "2021-05-12"], data.table(model = paste0("Excluding ", donor_states_list[s])))
  leave.one.out.results
})

leave.one.out.results.dose1 <- rbindlist(leave.one.out.results.dose1.dtl)

# Estimation: total COVID-19 cases per 100,000 state population

baseline.panel.cases <- copy(synthpanel.cases[(fips == 39 | donor_pool == 1)])

leave.one.out.results.cases.dtl <- lapply(1:length(donor_states_list), function(s) {
  print(paste0("Estimating model for cases leaving out ", donor_states_list[s]))
  leave.one.out.est <- augsynth(covid_total_cases_per100kpop ~ ohio_post |
                                  popdensity_2020 +
                                  gdp_per_capita_2020 +
                                  gop_pct_2020 +
                                  influenza_vaccination_pct_2019 +
                                  moveidx_retail_recreation +
                                  moveidx_grocery_pharmacy +
                                  moveidx_parks +
                                  moveidx_transit +
                                  moveidx_workplaces +
                                  moveidx_residential +
                                  miles_vacsite_50th_pctl +
                                  miles_vacsite_95th_pctl
                                , unit = fips, time = date, 
                                data = baseline.panel.cases[stname != donor_states_list[s]], progfun = "Ridge", fixedeff = TRUE)
  leave.one.out.results <- summary(leave.one.out.est , inf = TRUE, inf_type = "conformal")$att
  leave.one.out.results <- cbind(data.table(leave.one.out.results)[Time >= "2021-05-12"], data.table(model = paste0("Excluding ", donor_states_list[s])))
  leave.one.out.results
})

leave.one.out.results.cases <- rbindlist(leave.one.out.results.cases.dtl)

# Estimation: cumulative total COVID-19 ICU patient-days per 100,000 population

baseline.panel.icu <- copy(synthpanel.icu[(fips == 39 | donor_pool == 1)])

leave.one.out.results.icu.dtl <- lapply(1:length(donor_states_list), function(s) {
  print(paste0("Estimating model for icu leaving out ", donor_states_list[s]))
  leave.one.out.est <- augsynth(covid_icu_patdays_per100kpop ~ ohio_post |
                                  popdensity_2020 +
                                  gdp_per_capita_2020 +
                                  gop_pct_2020 +
                                  influenza_vaccination_pct_2019 +
                                  moveidx_retail_recreation +
                                  moveidx_grocery_pharmacy +
                                  moveidx_parks +
                                  moveidx_transit +
                                  moveidx_workplaces +
                                  moveidx_residential +
                                  miles_vacsite_50th_pctl +
                                  miles_vacsite_95th_pctl
                                , unit = fips, time = date, 
                                data = baseline.panel.icu[stname != donor_states_list[s]], progfun = "Ridge", fixedeff = TRUE)
  leave.one.out.results <- summary(leave.one.out.est , inf = TRUE, inf_type = "conformal")$att
  leave.one.out.results <- cbind(data.table(leave.one.out.results)[Time >= "2021-05-12"], data.table(model = paste0("Excluding ", donor_states_list[s])))
  leave.one.out.results
})

leave.one.out.results.icu <- rbindlist(leave.one.out.results.icu.dtl)

# Clean up the workspace

rm(baseline.panel.dose1, baseline.panel.cases, baseline.panel.icu, donor_states_list,
   leave.one.out.results.dose1.dtl, leave.one.out.results.cases.dtl, leave.one.out.results.icu.dtl)

#### FIGURE: GRAPH THE ESTIMATES FOR EACH OF THE MODELS FOR EACH OF THE OUTCOMES ####

# Graph: total dose 1 vaccinations per 100 state population

all.results.dose1 <- rbind(baseline.results.dose1, classicscm.results.dose1, residualized.results.dose1,
                           allstates.results.dose1, leave.one.out.results.dose1, fill = TRUE)

gg.results.dose1 <- all.results.dose1[Time == maxdate.vaccinations, .(model, estimate = Estimate, lower_bound, upper_bound)]
gg.results.dose1[, y_position := .N - .I + 1]

ggplot(gg.results.dose1) + 
  geom_vline(xintercept = 0.0, color = "black", linetype = "solid") +
  geom_vline(xintercept = gg.results.dose1[model == "Baseline model"]$estimate, color = "#bb0000", linetype = "dashed") +
  geom_errorbarh(aes(y = y_position, xmin = lower_bound, xmax = upper_bound), color = "grey30", size = 0.25) +
  geom_point(aes(x = estimate, y = y_position), size = 2) +
  geom_point(data = gg.results.dose1[model == "Baseline model"], aes(x = estimate, y = y_position), color = "#bb0000", size = 2.1) +
  scale_x_continuous(name = "Estimate", limits = c(-1, 2), breaks = c(-1, 0, 1, 2)) +
  scale_y_continuous(name = "Model", breaks = gg.results.dose1$y_position, labels = gg.results.dose1$model, expand = c(0.005, 0.005)) +
  theme_bw() + 
  theme(panel.grid.minor = element_blank(), panel.grid.major.x = element_blank(), axis.text.y = element_text(size = 10))

ggsave(file.path(figuresdir, "Robustness_Population_Share_Any_Vaccination.pdf"), width = 8, height = 10, units = "in", dpi = 300)

# Graph: total COVID-19 cases per 100,000 state population

all.results.cases <- rbind(baseline.results.cases, classicscm.results.cases, residualized.results.cases,
                           allstates.results.cases, leave.one.out.results.cases, fill = TRUE)

gg.results.cases <- all.results.cases[Time == maxdate.cases, .(model, estimate = Estimate, lower_bound, upper_bound)]
gg.results.cases[, y_position := .N - .I + 1]

ggplot(gg.results.cases) + 
  geom_vline(xintercept = 0.0, color = "black", linetype = "solid") +
  geom_vline(xintercept = gg.results.cases[model == "Baseline model"]$estimate, color = "#bb0000", linetype = "dashed") +
  geom_errorbarh(aes(y = y_position, xmin = lower_bound, xmax = upper_bound), color = "grey30", size = 0.25) +
  geom_point(aes(x = estimate, y = y_position), size = 2) +
  geom_point(data = gg.results.cases[model == "Baseline model"], aes(x = estimate, y = y_position), color = "#bb0000", size = 2.1) +
  scale_x_continuous(name = "Estimate", limits = c(-250, 10), breaks = c(-250, -200, -150, -100, -50, 0)) +
  scale_y_continuous(name = "Model", breaks = gg.results.cases$y_position, labels = gg.results.cases$model, expand = c(0.005, 0.005)) +
  theme_bw() + 
  theme(panel.grid.minor = element_blank(), panel.grid.major.x = element_blank(), axis.text.y = element_text(size = 10))

ggsave(file.path(figuresdir, "Robustness_COVID19_Cases_Per_100k.pdf"), width = 8, height = 10, units = "in", dpi = 300)

# Graph: cumulative total COVID-19 ICU patient-days per 100,000 population

all.results.icu <- rbind(baseline.results.icu, classicscm.results.icu, residualized.results.icu,
                         allstates.results.icu, leave.one.out.results.icu, fill = TRUE)

gg.results.icu <- all.results.icu[Time == maxdate.icu, .(model, estimate = Estimate, lower_bound, upper_bound)]
gg.results.icu[, y_position := .N - .I + 1]

ggplot(gg.results.icu) + 
  geom_vline(xintercept = 0.0, color = "black", linetype = "solid") +
  geom_vline(xintercept = gg.results.icu[model == "Baseline model"]$estimate, color = "#bb0000", linetype = "dashed") +
  geom_errorbarh(aes(y = y_position, xmin = lower_bound, xmax = upper_bound), color = "grey30", size = 0.25) +
  geom_point(aes(x = estimate, y = y_position), size = 2) +
  geom_point(data = gg.results.icu[model == "Baseline model"], aes(x = estimate, y = y_position), color = "#bb0000", size = 2.1) +
  scale_x_continuous(name = "Estimate", limits = c(-75, 5), breaks = c(-75, -50, -25, 0)) +
  scale_y_continuous(name = "Model", breaks = gg.results.icu$y_position, labels = gg.results.icu$model, expand = c(0.005, 0.005)) +
  theme_bw() + 
  theme(panel.grid.minor = element_blank(), panel.grid.major.x = element_blank(), axis.text.y = element_text(size = 10))

ggsave(file.path(figuresdir, "Robustness_COVID19_ICU_Patient_Days_Per_100k.pdf"), width = 8, height = 10, units = "in", dpi = 300)

# Clean up the workspace

rm(baseline.results.dose1, classicscm.results.dose1, residualized.results.dose1,
   allstates.results.dose1, leave.one.out.results.dose1,
   baseline.results.cases, classicscm.results.cases, residualized.results.cases,
   allstates.results.cases, leave.one.out.results.cases,
   baseline.results.icu, classicscm.results.icu, residualized.results.icu,
   allstates.results.icu, leave.one.out.results.icu,
   gg.results.dose1, gg.results.cases, gg.results.icu)

#### ESTIMATE PLACEBO EFFECTS FOR EACH STATE IN THE DONOR POOL (AND OHIO) FOR THE SHARE OF POPULATION WITH ANY VACCINATION ####

# Including Ohio for comparison and rankings in the placebo table

donor_states_list <- unique(synthpanel.dose1[donor_pool == 1 | stname == "Ohio"]$stname)

# Estimation: total dose 1 vaccinations per 100 state population

placebo.results.dose1.dtl <- lapply(1:length(donor_states_list), function(s) {
  
  print(paste0("Estimating model for dose 1 placebo for ", donor_states_list[s]))
  placebo.panel <- copy(synthpanel.dose1[donor_pool == 1 | stname == "Ohio"])
  placebo.panel[, placebo_post := ifelse(stname == donor_states_list[s] & date >= "2021-05-12", 1, 0)]
  
  placebo.est <- augsynth(dose1_per_100pop ~ placebo_post |
                            popdensity_2020 +
                            gdp_per_capita_2020 +
                            gop_pct_2020 +
                            influenza_vaccination_pct_2019 +
                            moveidx_retail_recreation +
                            moveidx_grocery_pharmacy +
                            moveidx_parks +
                            moveidx_transit +
                            moveidx_workplaces +
                            moveidx_residential +
                            miles_vacsite_50th_pctl +
                            miles_vacsite_95th_pctl
                          , unit = fips, time = date, 
                          data = placebo.panel, progfun = "Ridge", fixedeff = TRUE)

  placebo.results <- summary(placebo.est , inf = TRUE, inf_type = "conformal")$att
  placebo.results <- cbind(data.table(placebo.results), data.table(stname = donor_states_list[s]))
  placebo.results
})

placebo.results.dose1 <- rbindlist(placebo.results.dose1.dtl)
rm(placebo.results.dose1.dtl)

#### FIGURE: PLOT THE RATIO OF THE POST-TREATMENT TO PRE-TREATMENT ROOT MEAN SQUARED PREDICTION ERROR FOR EACH PLACEBO STATE AND OHIO ####

# Calculate the pre-treatment and post-treatment RMSPE for each placebo state and for Ohio

placebo.rmspe.post <- placebo.results.dose1[Time >= "2021-05-12", .(post_rmspe = sqrt(mean(Estimate^2))), by = stname]
placebo.rmspe.pre <- placebo.results.dose1[Time < "2021-05-12", .(pre_rmspe = sqrt(mean(Estimate^2))), by = stname]
placebo.rmspe <- merge(placebo.rmspe.post, placebo.rmspe.pre, by = "stname")

# Define the RMSPE ratio, and rank the states

placebo.rmspe[, ratio_rmspe := post_rmspe / pre_rmspe]
setorder(placebo.rmspe, -ratio_rmspe)
placebo.rmspe[, rank_ratio_rmspe := .I]
placebo.rmspe[, bar_position := frank(-rank_ratio_rmspe)]

# Also define the ratio of the pre-treatment RMSPE to that of Ohio, and whether these ratios fall into one of several bins

placebo.rmspe[, ratio_pre_rmspe_ohio := pre_rmspe / placebo.rmspe[stname == "Ohio"]$pre_rmspe]
placebo.rmspe[ratio_pre_rmspe_ohio >= 15, bin_ratio_pre_rmspe_ohio := "1 Greater than 15"]
placebo.rmspe[ratio_pre_rmspe_ohio < 15 & ratio_pre_rmspe_ohio >= 5, bin_ratio_pre_rmspe_ohio := "2 Between 5 and 15"]
placebo.rmspe[ratio_pre_rmspe_ohio < 5, bin_ratio_pre_rmspe_ohio := "3 Less than 5"]
placebo.rmspe[stname == "Ohio", bin_ratio_pre_rmspe_ohio := "4 Ohio"]

# Plot and save the figure

ggplot(placebo.rmspe) +
  geom_bar(stat = "identity", aes(x = bar_position, y = ratio_rmspe, fill = bin_ratio_pre_rmspe_ohio), color = "white") +
  coord_flip() +
  scale_x_continuous(name = "Placebo state", breaks = placebo.rmspe$bar_position, labels = placebo.rmspe$stname) +
  scale_y_continuous(name = "Ratio of post-treatment to pre-treatment root mean squared prediction error", 
                     limits = c(0, 11.05), breaks = c(0, 2.5, 5, 7.5, 10)) +
  scale_fill_manual(name = "Ratio of pre-treatment\nRMSPE to that for Ohio", values = c("#ffcec1", "#f27255", "#bb0000", "black"), 
                    labels = c("Greater than 15X", "Between 5X and 15X", "Less than 5X", "Ohio")) +
  theme_bw() + 
  theme(panel.grid.minor = element_blank(),  axis.text.y = element_text(size = 10),
        legend.position = c(0.75, 0.75), legend.background = element_rect(color = "black", fill = "white"))

ggsave(file.path(figuresdir, "Synthetic_Control_Placebo_Results.pdf"), width = 8, height = 10, units = "in", dpi = 300)

# Clean up the workspace

rm(placebo.rmspe.post, placebo.rmspe.pre, placebo.rmspe)

#### PLOT THE PLACEBO ESTIMATES WITH 95 PERCENT CONFIDENCE INTERVALS FOR THE SHARE OF POPULATION WITH ANY VACCINATION ####

# Calculate the pre-treatment root mean square prediction error, and ratio to that for Ohio

pre.rmspe.dose1 <- placebo.results.dose1[Time < "2021-05-12", .(pre_rmspe_dose1 = sqrt(mean(Estimate^2))), by = stname]
pre.rmspe.dose1[, ratio_ohio_pre_rmspe_dose1 := pre_rmspe_dose1 / pre.rmspe.dose1[stname == "Ohio"]$pre_rmspe_dose1]
placebo.results.dose1 <- merge(placebo.results.dose1, pre.rmspe.dose1, by = "stname")

# Form the data for the graph

gg.placebos.dose1 <- placebo.results.dose1[Time == "2021-05-26", .(stname, estimate = Estimate, ratio_ohio_pre_rmspe_dose1, lower_bound, upper_bound, p_val)]
setorder(gg.placebos.dose1, -estimate)
gg.placebos.dose1[, y_position := .N - .I + 1]

# Plot including full donor pool

ggplot(gg.placebos.dose1) + 
  geom_vline(xintercept = 0.0, color = "black", linetype = "solid") +
  geom_vline(xintercept = gg.placebos.dose1[stname == "Ohio"]$lower_bound, color = "#bb0000", linetype = "dashed") +
  geom_vline(xintercept = gg.placebos.dose1[stname == "Ohio"]$upper_bound, color = "#bb0000", linetype = "dashed") +
  geom_errorbarh(aes(y = y_position, xmin = lower_bound, xmax = upper_bound), color = "grey30", size = 0.25) +
  geom_point(aes(x = estimate, y = y_position), size = 2) +
  geom_point(data = gg.placebos.dose1[stname == "Ohio"], aes(x = estimate, y = y_position), color = "#bb0000", size = 2.1) +
  scale_x_continuous(name = "Estimate", limits = c(-10, 10), breaks = c(-10, -5, 0, 5, 10)) +
  scale_y_continuous(name = "State", breaks = gg.placebos.dose1$y_position, labels = gg.placebos.dose1$stname, expand = c(0.005, 0.005)) +
  theme_bw() + 
  theme(panel.grid.minor = element_blank(), panel.grid.major.x = element_blank(), axis.text.y = element_text(size = 10))

ggsave(file.path(figuresdir, "Synthetic_Control_Placebo_Results_Conformal.pdf"), width = 8, height = 5, units = "in", dpi = 300)

# Plot including only donor pool states with pre-treatment RMSPE less than 10X that of Ohio

gg.placebos.dose1.sub10 <- gg.placebos.dose1[ratio_ohio_pre_rmspe_dose1 < 10]
gg.placebos.dose1.sub10[, y_position := .N - .I + 1]

ggplot(gg.placebos.dose1.sub10) + 
  geom_vline(xintercept = 0.0, color = "black", linetype = "solid") +
  geom_vline(xintercept = gg.placebos.dose1[stname == "Ohio"]$lower_bound, color = "#bb0000", linetype = "dashed") +
  geom_vline(xintercept = gg.placebos.dose1[stname == "Ohio"]$upper_bound, color = "#bb0000", linetype = "dashed") +
  geom_errorbarh(aes(y = y_position, xmin = lower_bound, xmax = upper_bound), color = "grey30", size = 0.25) +
  geom_point(aes(x = estimate, y = y_position), size = 2) +
  geom_point(data = gg.placebos.dose1.sub10[stname == "Ohio"], aes(x = estimate, y = y_position), color = "#bb0000", size = 2.1) +
  scale_x_continuous(name = "Estimate", limits = c(-5, 5), breaks = c(-5, -2.5, 0, 2.5, 5)) +
  scale_y_continuous(name = "State", breaks = gg.placebos.dose1.sub10$y_position, labels = gg.placebos.dose1.sub10$stname, expand = c(0.005, 0.005)) +
  theme_bw() + 
  theme(panel.grid.minor = element_blank(), panel.grid.major.x = element_blank(), axis.text.y = element_text(size = 10))

ggsave(file.path(figuresdir, "Synthetic_Control_Placebo_Results_Conformal_Sub10X.pdf"), width = 8, height = 5, units = "in", dpi = 300)

# Clean up the workspace

rm(pre.rmspe.dose1, gg.placebos.dose1, gg.placebos.dose1.sub10)

#### END ####
